@@ -8,6 +8,9 @@ use constant SubscriptionExpired => "subscription_expired";
 use constant SubscriptionTrialEnded => "subscription_trial_ended";
 use constant SubscriptionWentActive => "subscription_went_active";
 use constant SubscriptionWentPastDue => "subscription_went_past_due";
+use constant SubMerchantAccountApproved => "sub_merchant_account_approved";
+use constant SubMerchantAccountDeclined => "sub_merchant_account_declined";
+use constant TransactionDisbursed => "transaction_disbursed";
 
 use constant All => (
   SubscriptionCanceled,
@@ -17,6 +20,9 @@ use constant All => (
   SubscriptionTrialEnded,
   SubscriptionWentActive,
   SubscriptionWentPastDue,
+  SubMerchantAccountApproved,
+  SubMerchantAccountDeclined,
+  TransactionDisbursed,
 );
 
 1;
